Hospitals in Provinces
=======================

This example demonstrates how to find hospitals in specific provinces in Italy and aggregate their data.

This example shows how to:

1. Load geospatial data from GeoPackage files using ``geopackage_to_dataframe``
2. Filter data to select specific provinces (Milan and Cremona)
3. Perform a spatial join between provinces and hospitals using ``spatial_join``
4. Aggregate data to count hospitals and calculate total and average beds using ``spatial_aggregation``


.. toctree::

   /_collections/notebooks/hospitals_in_provinces.ipynb